# cherv-say-python
## Описание
Аналог CowSay, только вместо коровы - червяк.
## Установка и использование
### Установка:
```bash
pip install cherv
```
### Использование:
```bash
cherv [your message]
```
### Команды:
```bash
cherv --help  # выводит справку по использованию
```
```bash
cherv --skin  # позволяет изменить облик червя
```
## Скриншоты:


![Снимок экрана 2024-06-06 160033](https://github.com/AyaalTech/wormsay-python/assets/80465121/7b82236f-6551-4565-adf7-ba283e0f12e0)

